import React, { useState } from "react";
import Paper from "@material-ui/core/Paper";
import FormControl from "@material-ui/core/FormControl";
import Typography from "@material-ui/core/Typography";
import Button from "@material-ui/core/Button";
import ArrowForward from "@material-ui/icons/ArrowForward";
import { TextField } from "@material-ui/core";
import FormLabel from "@material-ui/core/FormLabel";

import { useDispatch, useSelector } from "react-redux";
import { actions } from "atp-authentication-binder-v2";

const validateEmail = RegExp(
  /^(([^<>()\[\]\.,;:\s@\"]+(\.[^<>()\[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i
);

const ForgetPassword = (props) => {
  const dispatch = useDispatch();
  const { classes, handleLogin, handleCloseresetPassword, logo } = props;

  const [passwordInputs, setpasswordInputs] = useState({
    Email: "",
  });
  const [errors, setError] = useState({
    Email: "",
  });
  const handleChange = ({ target: { name, value } }) => {
    setpasswordInputs({ ...passwordInputs, [name]: value });
    checkValidity(name, value);
  };

  const checkValidity = (name, value) => {
    switch (name) {
      case "Email": {
        if (!value) {
          setError({ ...errors, Email: "Email is required" });
        } else if (!validateEmail.test(value)) {
          setError({ ...errors, Email: "Please Enter Valid Email Id" });
        } else {
          setError({ ...errors, Email: "" });
        }
        break;
      }
    }
  };

  const validate = () => {
    let errorEmail = "";
    if (!passwordInputs.Email) {
      errorEmail = "Email Id Is Required";
    } else if (!validateEmail.test(passwordInputs.Email)) {
      errorEmail = "Please enter valid Email Id";
    }

    if (errorEmail) {
      setError({
        Email: errorEmail,
      });
      return false;
    } else {
      return true;
    }
  };

  const handleSubmit = (event) => {
    event.preventDefault();

    const Validate = validate();

    if (Validate) {
      ResetPassord();
    }
  };

  const ResetPassord = async () => {
    await dispatch(
      actions.FORGOT_PASSWORD({ email: passwordInputs.Email })
    ).then((response) => {
      console.log("response", response);
      let errorss = false;
      if (response?.payload?.error === false) {
        errorss = false;
        handleCloseresetPassword(errorss, response?.payload?.message);
        setpasswordInputs({
          Email: "",
        });
      } else {
        errorss = true;
        handleCloseresetPassword(errorss, response?.payload?.message);
      }
    });
  };

  return (
    <Paper className={classes.paperWrap}>
      <div style={{ display: "flex", justifyContent: "center" }}>
        <img
          src={logo}
          alt="icon"
          style={{ width: "80px", height: "80px", objectFit: "cover" }}
        />
      </div>
      <div className={classes.topBar}>
        <Typography variant="h4" className={classes.title1}>
          Reset Password
        </Typography>
      </div>
      <div className={classes.centerContent}>
        <FormControl className={classes.formControl}>
          <FormLabel className={classes.label}>
            {" "}
            Email <span className={classes.spaninp}>*</span>
          </FormLabel>
          <TextField
            name="Email"
            onChange={handleChange}
            placeholder="Email"
            className={classes.field}
            value={passwordInputs.Email}
            variant="outlined"
            size="small"
          />
          {errors?.Email ? (
            <p className={classes.errorStyle}>{errors.Email}</p>
          ) : (
            ""
          )}
        </FormControl>

        <div className={classes.btnArea1}>
          <Button
            variant="contained"
            fullWidth
            className={classes.btn}
            size="small"
            type="submit"
            onClick={handleSubmit}
          >
            Reset Password
            <ArrowForward className={classes.rightIcon} />
          </Button>
        </div>
        <div className={classes.optArea}>
          <Button
            size="small"
            className={classes.buttonLink}
            onClick={handleLogin}
          >
            Back To Login
          </Button>
        </div>
      </div>
    </Paper>
  );
};

export default ForgetPassword;
