import React, { useState } from 'react';
import Paper from '@material-ui/core/Paper';
import FormControl from '@material-ui/core/FormControl';
import Typography from '@material-ui/core/Typography';
import Visibility from '@material-ui/icons/Visibility';
import VisibilityOff from '@material-ui/icons/VisibilityOff';
import IconButton from '@material-ui/core/IconButton';
import InputAdornment from '@material-ui/core/InputAdornment';
import Button from '@material-ui/core/Button';
import CircularProgress from '@material-ui/core/CircularProgress';
import ArrowForward from '@material-ui/icons/ArrowForward';
import { TextField } from '@material-ui/core';
import FormLabel from '@material-ui/core/FormLabel';
import { useDispatch } from "react-redux";
import { actions } from "atp-authentication-binder-v2";
import config from "../../utils/config";
import md5 from 'md5';


const validateEmail = RegExp(
    /^(([^<>()\[\]\.,;:\s@\"]+(\.[^<>()\[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i
);

const Login = (props) => {
    const dispatch = useDispatch();
    const { classes, handleForgetPassword, handleSignup, handleCloseLogin, showSignUp, showReset, logo } = props
    const [showPassword, setShowPassword] = useState(false);
    const handleClickShowPassword = () => setShowPassword(!showPassword);
    const handleMouseDownPassword = event => event.preventDefault();

    const [loginInputs, setloginInputs] = useState({
        Email: "",
        Password: ""
    })

    const [errors, setErrors] = useState({

        Email: "",
        Password: ""
    })

    const [loading, setLoading] = useState(false);

    // Input Change

    const handleChange = ({ target: { name, value } }) => {
        setloginInputs({ ...loginInputs, [name]: value })
    }


    // Error Handling

    const validate = () => {
        let errorEmail = "";
        let errorPassword = "";
        if (!loginInputs.Email) {
            errorEmail = "Email Id Is Required"
        }

        else if (!validateEmail.test(loginInputs.Email)) {
            errorEmail = "Please enter valid Email Id"
        }

        if (!loginInputs.Password) {
            errorPassword = "Password Is Required"
        }

        if (errorEmail || errorPassword) {
            setErrors({
                Email: errorEmail,
                Password: errorPassword
            })
            return false
        }
        else {

            return true
        }

    }

    // Submit
    const handleSubmit = (event) => {
        event.preventDefault();
        userLogin();

    }

    const userLogin = async () => {

        const Validate = validate();

        if (Validate) {

            await dispatch(actions.LOGIN({ username: loginInputs.Email, password: loginInputs.Password })).then((response) => {


                let errorss = false;
                if (response?.payload?.data?.Code === "201") {

                    const data = {

                        facilityid: "",
                        roleid: response?.payload?.Persondata?.result[0]?.roleid[0]?.roleid,
                        locationid: "",
                        personid: response?.payload?.Persondata?.result[0]._id,
                        enterpriseid: "",
                        orgid: "",
                        apikey: config.Api_Key
                    }


                  const datas = JSON.stringify(data).toString();

                    localStorage.setItem("keyclkId", response?.payload?.data?.keyclkId);
                    localStorage.setItem("access_token", response?.payload?.data?.tokenDetails?.access_token);
                    localStorage.setItem("RoleId", response?.payload?.Persondata?.result[0]?.roleid[0]?.roleid);
                    localStorage.setItem("tenentid", response?.payload?.Persondata?.result[0]?.tenantid);
                    localStorage.setItem(
                        "permissionData",
                        btoa(
                            JSON.stringify(response?.payload?.Permissiondata[0]?.permission[0]?.permissionRepoAccess)
                        ))
                        const checksum = md5(datas);

                        const payload = {
                            facilityid: "",
                            roleid: response?.payload?.Persondata?.result[0]?.roleid[0]?.roleid,
                            locationid: "",
                            personid: response?.payload?.Persondata?.result[0]._id,
                            enterpriseid: "",
                            orgid: "",
                            CheckSum: checksum
                        }


                    errorss = false
                    generatetoken(payload)

                }

                else {
                    errorss = true
                    handleCloseLogin(errorss, response?.payload?.message)
                }
            })

        }

    }


    const generatetoken = async (data) => {
        let errorss = false;
        await dispatch(actions.GENERATEJWT({ datass: data })).then((res) => {
            localStorage.setItem("queue_token", res?.payload?.Result);
            handleCloseLogin(errorss, "Login Succesfully")
                    setloginInputs({
                        Email: "",
                        Password: ""
                    })
        })

    }

    // const getPersondetails = async (Keyclockid) => {
    //     let errorss = false;

    //     const data = await dispatch(actions.GETPERSON({ clockid: Keyclockid }));
    //     if (data?.payload?.error === false) {
    //         if (data?.payload?.Result[0]?.roleid !== undefined) {
    //             localStorage.setItem("RoleId", data?.payload?.Result[0]?.roleid);
    //             localStorage.setItem("tenentid", data?.payload?.Result[0]?.tenantid);
    //             getpermission_details(data?.payload?.Result[0]?.roleid)
    //         }

    //         else {
    //             errorss = true
    //             handleCloseLogin(errorss, "Role Not Mapped For User")
    //         }

    //     }

    //     else {
    //         errorss = true
    //         handleCloseLogin(errorss, response?.payload?.data?.message)
    //     }


    // }

    // const getpermission_details = async (roleid) => {
    //     const data = await dispatch(actions.GETPERMISSION({ roleid: roleid }));
    //     let errorss = false;
    //     if (data?.payload?.error === false) {
    //         if (data?.payload?.Result[0]?.permission[0]?.permissionRepoAccess !== undefined) {
    //             localStorage.setItem(
    //                 "permissionData",
    //                 btoa(
    //                     JSON.stringify(data?.payload?.Result[0]?.permission[0]?.permissionRepoAccess)
    //                 ))
    //             errorss = false
    //             handleCloseLogin(errorss, "Login Succesfully")
    //             setloginInputs({
    //                 Email: "",
    //                 Password: ""
    //             })
    //         }
    //         else {
    //             errorss = true
    //             handleCloseLogin(errorss, "Role Not Mapped For User")
    //         }
    //     }

    //     else {
    //         errorss = true
    //         handleCloseLogin(errorss, response?.payload?.data?.message)
    //     }

    // }

    return (
        <Paper className={classes.paperWrap}>
            <form>
                <div style={{ display: "flex", justifyContent: "center" }}>
                    <img
                        src={logo}
                        alt="icon"
                        style={{ width: "80px", height: "80px", objectFit: "cover" }}
                    />
                </div>
                <div className={classes.topBar}>
                    <Typography variant="h4" className={classes.title}>
                        Sign In
                    </Typography>

                </div>
                <div className={classes.centerContent}>
                    <FormControl className={classes.formControl}>
                        <FormLabel className={classes.label}> Email <span className={classes.spaninp}>*</span></FormLabel>
                        <TextField
                            name="Email"
                            onChange={handleChange}
                            placeholder="Email"
                            className={classes.field}
                            value={loginInputs.Email}
                            variant="outlined"
                            size="small"

                        />
                        {errors?.Email ? (
                            <p className={classes.errorStyle}>{errors.Email}</p>
                        ) :
                            (
                                ''
                            )}
                    </FormControl>

                    <FormControl className={classes.formControl}>
                        <FormLabel className={classes.label}> Password <span className={classes.spaninp}>*</span></FormLabel>
                        <TextField
                            name="Password" onChange={handleChange}
                            value={loginInputs.Password}
                            type={showPassword ? 'text' : 'password'}
                            variant="outlined"
                            size="small"
                            autocomplete="on"
                            InputProps={{
                                endAdornment: (
                                    <InputAdornment position="end">
                                        <IconButton
                                            aria-label="Toggle password visibility"
                                            onClick={handleClickShowPassword}
                                            onMouseDown={handleMouseDownPassword}
                                        >
                                            {showPassword ? <VisibilityOff /> : <Visibility />}
                                        </IconButton>
                                    </InputAdornment>
                                )
                            }}
                            className={classes.field}
                        />
                        {errors?.Password ? (
                            <p className={classes.errorStyle}>{errors.Password}</p>
                        ) :
                            (
                                ''
                            )}
                    </FormControl>
                    {showReset ?
                        <div className={classes.optArea1}>

                            <Button size="small" className={classes.buttonLink} onClick={handleForgetPassword}>
                                Forget Password?
                            </Button>
                        </div>
                        :
                        null
                    }

                    <div className={classes.btnArea}>
                        <Button variant="contained" disabled={loading} className={classes.btn} fullWidth size="small" type="button" onClick={handleSubmit}>
                            {loading && <CircularProgress size={24} className={classes.buttonProgress} />}
                            Login
                            {!loading && <ArrowForward className={classes.rightIcon} />}
                        </Button>
                    </div>

                    {showSignUp ?
                        <div className={classes.optArea}>
                            <Button size="small" className={classes.buttonLink} onClick={handleSignup}  >
                                <ArrowForward className={classes.rightIcon} />
                                Sign Up
                            </Button>

                        </div>
                        :
                        null
                    }
                </div>
            </form>
        </Paper>

    )
}

export default Login;